@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import os
 import logging
 import re
 
@@ -42,7 +41,7 @@ class PartCategory(inventree.base.InventreeObject):
                          fetch_parent=fetch_parent)
 
 
-class Part(inventree.base.InventreeObject):
+class Part(inventree.base.ImageMixin, inventree.base.InventreeObject):
     """ Class representing the Part database model """
 
     URL = 'part'
@@ -75,46 +74,14 @@ class Part(inventree.base.InventreeObject):
         """ Return the stock items associated with this part """
         return inventree.stock.StockItem.list(self._api, part=self.pk)
 
-    def getAttachments(self):
-        """ Return attachments associated with this part """
-        return PartAttachment.list(self._api, part=self.pk)
-
     def getParameters(self):
         """ Return parameters associated with this part """
-        return inventree.base.Parameter.list(self._api, part=self.pk)
+        return Parameter.list(self._api, part=self.pk)
 
     def getRelated(self):
         """ Return related parts associated with this part """
         return PartRelated.list(self._api, part=self.pk)
 
-    def uploadImage(self, image):
-        """
-        Upload an image against this Part
-
-        args:
-            - image: path to an image file
-        
-        Returns the HTTP response object
-        """
-
-        files = {}
-
-        if image:
-            if os.path.exists(image):
-                f = os.path.basename(image)
-                fo = open(image, 'rb')
-                files['image'] = (f, fo)
-            else:
-                logger.error("File does not exist: '{f}'".format(f=image))
-                return None
-
-        response = self.save(
-            data={},
-            files=files
-        )
-
-        return response
-
     def getInternalPriceList(self):
         """
         Returns the InternalPrice list for this part
@@ -129,16 +96,24 @@ class Part(inventree.base.InventreeObject):
 
         return InternalPrice.setInternalPrice(self._api, self.pk, quantity, price)
 
-    def downloadImage(self, destination):
+    def getAttachments(self):
+        return PartAttachment.list(self._api, part=self.pk)
+
+    def uploadAttachment(self, attachment, comment=''):
         """
-        Download the image for this Part, to the specified destination
+        Upload an attachment (file) against this Part.
+
+        Args:
+            attachment: Either a string (filename) or a file object
+            comment: Attachment comment
         """
 
-        if self.image:
-            return self._api.downloadFile(self.image, destination)
-        else:
-            logger.error(f"Part '{self.name}' does not have an associated image")
-            return False
+        return PartAttachment.upload(
+            self._api,
+            attachment,
+            comment=comment,
+            part=self.pk
+        )
 
 
 class PartAttachment(inventree.base.Attachment):
@@ -146,50 +121,7 @@ class PartAttachment(inventree.base.Attachment):
 
     URL = 'part/attachment'
 
-    @classmethod
-    def upload_attachment(cls, api, part, **kwargs):
-        """
-        Upload a Part attachment
-
-        args:
-            api: Authenticated InvenTree API object
-            part: pk of the Part object to upload the attachment to
-
-        kwargs:
-            attachment: Attach a file
-            comment: Add comment
-        """
-        attachment = kwargs.get('attachment', None)
-
-        files = {}
-
-        fo = None
-
-        if attachment:
-            if os.path.exists(attachment):
-                f = os.path.basename(attachment)
-                fo = open(attachment, 'rb')
-                files['attachment'] = (f, fo)
-            else:
-                logger.error("File does not exist: '{f}'".format(f=attachment))
-
-        comment = kwargs.get('comment', '')
-
-        data = {
-            'part': part,
-            'attachment': os.path.basename(attachment),
-            'comment': comment,
-        }
-
-        # Send the data to the server
-        if api.post(cls.URL, data, files=files):
-            logger.info("Uploaded attachment: '{f}'".format(f=attachment))
-            ret = True
-        else:
-            logger.warning("Attachment upload failed")
-            ret = False
-
-        return ret
+    REQUIRED_KWARGS = ['part']
 
 
 class PartTestTemplate(inventree.base.InventreeObject):
@@ -260,3 +192,21 @@ class PartRelated(inventree.base.InventreeObject):
             logging.warning("Related failed")
             ret = False
         return ret
+
+
+class Parameter(inventree.base.InventreeObject):
+    """class representing the Parameter database model """
+    URL = 'part/parameter'
+
+    def getunits(self):
+        """ Get the dimension and units for this parameter """
+
+        return [element for element
+                in ParameterTemplate.list(self._api)
+                if element['pk'] == self._data['template']]
+
+
+class ParameterTemplate(inventree.base.InventreeObject):
+    """ class representing the Parameter Template database model"""
+
+    URL = 'part/parameter/template'
